import React, { useEffect, useRef, useState } from 'react';
import { Modal, Pressable, StatusBar, StyleSheet, View, Animated, Dimensions } from 'react-native';
import { Theme } from '../Styles/theme';
const { height: WINDOW_HEIGHT } = Dimensions.get('window');
const SCREEN_HEIGHT = WINDOW_HEIGHT + (StatusBar.currentHeight || 0);
const Popup = props => {
    const { children, visible, closeOnClickOverlay = false, barStyle = 'dark-content', onClose, onAnimationStart, onAnimationEnd, } = props;
    const [innerVisible, setInnerVisible] = useState(false);
    const slideAnim = useRef(new Animated.Value(SCREEN_HEIGHT)).current;
    useEffect(() => {
        if (visible) {
            setInnerVisible(true);
            onAnimationStart?.();
            Animated.timing(slideAnim, {
                toValue: 0,
                duration: 700,
                useNativeDriver: false,
            }).start();
        }
        else {
            Animated.timing(slideAnim, {
                toValue: SCREEN_HEIGHT,
                duration: 500,
                useNativeDriver: false,
            }).start(() => {
                setInnerVisible(false);
                onAnimationEnd?.();
            });
        }
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, [visible]);
    return (React.createElement(Modal, { transparent: true, statusBarTranslucent: true, hardwareAccelerated: true, visible: innerVisible, animationType: "fade", onRequestClose: onClose },
        React.createElement(StatusBar, { barStyle: barStyle }),
        React.createElement(View, { style: styles.container },
            React.createElement(Animated.View, { style: [styles.animate, { top: slideAnim }] },
                React.createElement(Pressable, { style: styles.mask, onPress: closeOnClickOverlay ? onClose : undefined }),
                React.createElement(View, { style: styles.content }, children)))));
};
const styles = StyleSheet.create({
    container: {
        flex: 1,
        backgroundColor: Theme.fillMask,
    },
    animate: {
        position: 'absolute',
        left: 0,
        right: 0,
        bottom: 0,
    },
    mask: {
        flex: 1,
    },
    content: {},
});
export default Popup;
